@@ -13,7 +13,7 @@ our @EXPORT_OK = qw(datapack_modules);
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2021-08-29'; # DATE
 our $DIST = 'Module-DataPack'; # DIST
-our $VERSION = '0.221'; # VERSION
+our $VERSION = '0.222'; # VERSION
 
 our %SPEC;
 
@@ -171,7 +171,7 @@ _
         my $debug = $ENV{PERL_DATAPACKER_DEBUG};
         if ($debug) {
             my @caller0 = caller;
-            warn "[datapacker] Hook called with arguments: (".join(",", @_).") by $caller0[1] line $caller0[2]\n";
+            warn "[datapacker] Hook called with arguments: (".join(",", @_).") by package $caller0[0] in file $caller0[1] line $caller0[2]\n";
         }
 
         $toc ||= do {
@@ -304,7 +304,7 @@ Module::DataPack - Like Module::FatPack, but uses datapacking instead of fatpack
 
 =head1 VERSION
 
-This document describes version 0.221 of Module::DataPack (from Perl distribution Module-DataPack), released on 2021-08-29.
+This document describes version 0.222 of Module::DataPack (from Perl distribution Module-DataPack), released on 2021-08-29.
 
 =head1 FUNCTIONS
 
